package com.goldenwater.slaj.stan.service;

import java.util.List;
import com.goldenwater.slaj.stan.domain.BisStanScore;

public interface IBisStanScoreService {
    BisStanScore selectBisStanScoreByGuid(String guid);
    List<BisStanScore> selectBisStanScoreList(BisStanScore entity);
    int insertBisStanScore(BisStanScore entity);
    int updateBisStanScore(BisStanScore entity);
    int deleteBisStanScoreByGuid(String guid);
    int deleteBisStanScoreByGuids(String[] guids);
}
